==> u++_5.0.1.orig.tar.gz: u++-5.0.1/src/scheduler/uDeadlineMonotonic1.h <==
//                              -*- Mode: C++ -*- 
// 
// uC++ Version 5.0.1, Copyright (C) Philipp E. Lim 1996
// 
// uDeadlineMonotonic.h -- 
// 
// Author           : Philipp E. Lim and Ashif S. Harji
// Created On       : Fri Jul 19 23:20:17 1996
// Last Modified By : Peter A. Buhr
// Last Modified On : Thu Jun 28 16:58:32 2001
// Update Count     : 239
//
// This  library is free  software; you  can redistribute  it and/or  modify it
// under the terms of the GNU Lesser General Public License as published by the
// Free Software  Foundation; either  version 2.1 of  the License, or  (at your
// option) any later version.
// 
// This library is distributed in the  hope that it will be useful, but WITHOUT
// ANY  WARRANTY;  without even  the  implied  warranty  of MERCHANTABILITY  or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
// for more details.
// 
// You should  have received a  copy of the  GNU Lesser General  Public License
// along  with this library.
// 


#ifndef __U_DEADLINEMONOTONIC1_H__
#define __U_DEADLINEMONOTONIC1_H__

#pragma __U_NOT_USER_CODE__


#include <uRealTime.h>
#include <uHeapQ.h>


class uDeadlineMonotonic1 : public uPriorityScheduleQSeq<uBaseTaskSeq, uBaseTaskDL> {
  public:
    void uAddInitialize( uSequence<uBaseTaskDL> &TaskList );
    void uRemoveInitialize( uSequence<uBaseTaskDL> & );
    void uRescheduleTask( uBaseTaskDL *TaskNode, uBaseTaskSeq &TaskList );
}; // uDeadlineMonotonic1


#pragma __U_USER_CODE__

#endif // __U_DEADLINEMONOTONIC1_H__


// Local Variables: //
// compile-command: "gmake install" //
// End: //

==> u++_5.3.0.orig.tar.gz: u++-5.3.0/src/scheduler/uDeadlineMonotonic1.h <==
//                              -*- Mode: C++ -*- 
// 
// uC++ Version 5.3.0, Copyright (C) Philipp E. Lim 1996
// 
// uDeadlineMonotonic.h -- 
// 
// Author           : Philipp E. Lim and Ashif S. Harji
// Created On       : Fri Jul 19 23:20:17 1996
// Last Modified By : Peter A. Buhr
// Last Modified On : Mon Oct 10 11:11:54 2005
// Update Count     : 241
//
// This  library is free  software; you  can redistribute  it and/or  modify it
// under the terms of the GNU Lesser General Public License as published by the
// Free Software  Foundation; either  version 2.1 of  the License, or  (at your
// option) any later version.
// 
// This library is distributed in the  hope that it will be useful, but WITHOUT
// ANY  WARRANTY;  without even  the  implied  warranty  of MERCHANTABILITY  or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
// for more details.
// 
// You should  have received a  copy of the  GNU Lesser General  Public License
// along  with this library.
// 


#ifndef __U_DEADLINEMONOTONIC1_H__
#define __U_DEADLINEMONOTONIC1_H__

#pragma __U_NOT_USER_CODE__


#include <uRealTime.h>
#include <uHeapQ.h>


class uDeadlineMonotonic1 : public uPriorityScheduleQSeq<uBaseTaskSeq, uBaseTaskDL> {
  public:
    void addInitialize( uSequence<uBaseTaskDL> &TaskList );
    void removeInitialize( uSequence<uBaseTaskDL> & );
    void uRescheduleTask( uBaseTaskDL *TaskNode, uBaseTaskSeq &TaskList );
}; // uDeadlineMonotonic1


#pragma __U_USER_CODE__

#endif // __U_DEADLINEMONOTONIC1_H__


// Local Variables: //
// compile-command: "gmake install" //
// End: //
